<?php

namespace ServiceType;

use \WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for Business ServiceType
 * @subpackage Services
 */
class Business extends AbstractSoapClientBase
{
    /**
     * Sets the HeaderLogin SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderLoginType $headerLogin
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderLogin(\StructType\HeaderLoginType $headerLogin, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderLogin', $headerLogin, $mustUnderstand, $actor);
    }
    /**
     * Sets the HeaderAuthenticate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \StructType\HeaderAuthenticateType $headerAuthenticate
     * @param string $nameSpace
     * @param bool $mustUnderstand
     * @param string $actor
     * @return bool
     */
    public function setSoapHeaderHeaderAuthenticate(\StructType\HeaderAuthenticateType $headerAuthenticate, $nameSpace = 'http://www.webservices.nl/soap/', $mustUnderstand = false, $actor = null)
    {
        return $this->setSoapHeader($nameSpace, 'HeaderAuthenticate', $headerAuthenticate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named businessGetEstablishmentNumber
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve the establishment number (Dutch 'Vestigingsnummer') for a business.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetEstablishmentNumberRequestType $parameters
     * @return \StructType\BusinessGetEstablishmentNumberResponseType|bool
     */
    public function businessGetEstablishmentNumber(\StructType\BusinessGetEstablishmentNumberRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetEstablishmentNumber($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessGetBIKDescription
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a BIK ('Bedrijfsindeling kamers van koophandel') code, which is the type of code returned in a <BusinessDossier> as the Primary or Secondary activity code. The description for all levels of the BIK code is returned, even if
     * the full length BIK code does not exist. Descriptions of the section associated with the BIK code is also returned.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetBIKDescriptionRequestType $parameters
     * @return \StructType\BusinessGetBIKDescriptionResponseType|bool
     */
    public function businessGetBIKDescription(\StructType\BusinessGetBIKDescriptionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetBIKDescription($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessGetSBIDescription
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a SBI ('Standaard Bedrijfs Indeling 2008') code.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetSBIDescriptionRequestType $parameters
     * @return \StructType\BusinessGetSBIDescriptionResponseType|bool
     */
    public function businessGetSBIDescription(\StructType\BusinessGetSBIDescriptionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetSBIDescription($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessBIKToSBI
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessBIKToSBIRequestType $parameters
     * @return \StructType\BusinessBIKToSBIResponseType|bool
     */
    public function businessBIKToSBI(\StructType\BusinessBIKToSBIRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessBIKToSBI($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSBIToBIK
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSBIToBIKRequestType $parameters
     * @return \StructType\BusinessSBIToBIKResponseType|bool
     */
    public function businessSBIToBIK(\StructType\BusinessSBIToBIKRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSBIToBIK($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessGetDossierV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business Dossier. The subdossierno parameter can be left empty to get all Sub Dossiers of one Dossier.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetDossierV3RequestType $parameters
     * @return \StructType\BusinessGetDossierV3ResponseType|bool
     */
    public function businessGetDossierV3(\StructType\BusinessGetDossierV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetDossierV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessGetDossierExtended
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up an extended business Dossier.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetDossierExtendedRequestType $parameters
     * @return \StructType\BusinessGetDossierExtendedResponseType|bool
     */
    public function businessGetDossierExtended(\StructType\BusinessGetDossierExtendedRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetDossierExtended($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchDossierNumber
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business using its dossier number.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchDossierNumberRequestType $parameters
     * @return \StructType\BusinessSearchDossierNumberResponseType|bool
     */
    public function businessSearchDossierNumber(\StructType\BusinessSearchDossierNumberRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchDossierNumber($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchPostcode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business using its postcode address. nbcode is required, other parameters may be left empty.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchPostcodeRequestType $parameters
     * @return \StructType\BusinessSearchPostcodeResponseType|bool
     */
    public function businessSearchPostcode(\StructType\BusinessSearchPostcodeRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchPostcode($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Lookup a business using its address. Specified parameters are compared against both establishment and correspondence addresses to find a match. Parameters may be left empty.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchAddressRequestType $parameters
     * @return \StructType\BusinessSearchAddressResponseType|bool
     */
    public function businessSearchAddress(\StructType\BusinessSearchAddressRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchAddress($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchName
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Lookup a business using its name.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchNameRequestType $parameters
     * @return \StructType\BusinessSearchNameResponseType|bool
     */
    public function businessSearchName(\StructType\BusinessSearchNameRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchName($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchParameters
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business by a number of parameters. At least a tradename, neighborhood code, street, city or telephone number is required. Lookups based on postbus address are possible by specifying streetname "Postbus" and specifying the
     * postbus number in the houseno parameter. Specified address parameters are compared against both establishment and correspondence addresses to find a match.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchParametersRequestType $parameters
     * @return \StructType\BusinessSearchParametersResponseType|bool
     */
    public function businessSearchParameters(\StructType\BusinessSearchParametersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchParameters($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchParametersV3
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business by a number of parameters. At least a tradename, neighborhood code, street, city or telephone number is required. Lookups based on postbus address are possible by specifying streetname "Postbus" and specifying the
     * postbus number in the houseno parameter. Specified address parameters are compared against both establishment and correspondence addresses to find a match.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchParametersV3RequestType $parameters
     * @return \StructType\BusinessSearchParametersV3ResponseType|bool
     */
    public function businessSearchParametersV3(\StructType\BusinessSearchParametersV3RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchParametersV3($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchSelection
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business using its location and SBI code.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchSelectionRequestType $parameters
     * @return \StructType\BusinessSearchSelectionResponseType|bool
     */
    public function businessSearchSelection(\StructType\BusinessSearchSelectionRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchSelection($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchSelectionV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business using its location and SBI code.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchSelectionV2RequestType $parameters
     * @return \StructType\BusinessSearchSelectionV2ResponseType|bool
     */
    public function businessSearchSelectionV2(\StructType\BusinessSearchSelectionV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchSelectionV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessGetDossierSBI
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns the SBI codes and their descriptions for a dossier.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessGetDossierSBIRequestType $parameters
     * @return \StructType\BusinessGetDossierSBIResponseType|bool
     */
    public function businessGetDossierSBI(\StructType\BusinessGetDossierSBIRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessGetDossierSBI($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessUpdateCheckDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessUpdateCheckDossierRequestType $parameters
     * @return \StructType\BusinessUpdateCheckDossierResponseType|bool
     */
    public function businessUpdateCheckDossier(\StructType\BusinessUpdateCheckDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessUpdateCheckDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessUpdateGetChangedDossiers
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Retrieve dossier numbers for all dossiers changed since the given date.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessUpdateGetChangedDossiersRequestType $parameters
     * @return \StructType\BusinessUpdateGetChangedDossiersResponseType|bool
     */
    public function businessUpdateGetChangedDossiers(\StructType\BusinessUpdateGetChangedDossiersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessUpdateGetChangedDossiers($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessUpdateGetDossiers
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Returns a list of all dossiers that have been updated since they were last retrieved by the user
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessUpdateGetDossiersRequestType $parameters
     * @return \StructType\BusinessUpdateGetDossiersResponseType|bool
     */
    public function businessUpdateGetDossiers(\StructType\BusinessUpdateGetDossiersRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessUpdateGetDossiers($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessUpdateAddDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Add a dossier to the list of dossiers for which the user (the user whose credentials are used to make the call) wants to receive updates
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessUpdateAddDossierRequestType $parameters
     * @return \StructType\BusinessUpdateAddDossierResponseType|bool
     */
    public function businessUpdateAddDossier(\StructType\BusinessUpdateAddDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessUpdateAddDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessUpdateRemoveDossier
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Remove a dossier from the list of dossiers for which the user (the user whose credentials are used to make the call) wants to receive updates.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessUpdateRemoveDossierRequestType $parameters
     * @return \StructType\BusinessUpdateRemoveDossierResponseType|bool
     */
    public function businessUpdateRemoveDossier(\StructType\BusinessUpdateRemoveDossierRequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessUpdateRemoveDossier($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Method to call the operation originally named businessSearchParametersV2
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: HeaderLogin, HeaderAuthenticate
     * - SOAPHeaderNamespaces: http://www.webservices.nl/soap/, http://www.webservices.nl/soap/
     * - SOAPHeaderTypes: \StructType\HeaderLoginType, \StructType\HeaderAuthenticateType
     * - SOAPHeaders: required, required
     * - documentation: Look up a business by a number of parameters. At least a tradename, neighborhood code, street, city or telephone number is required. Lookups based on postbus address are possible by specifying streetname "Postbus" and specifying the
     * postbus number in the houseno parameter. Specified address parameters are compared against both establishment and correspondence addresses to find a match.
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::getResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \StructType\BusinessSearchParametersV2RequestType $parameters
     * @return \StructType\BusinessSearchParametersV2ResponseType|bool
     */
    public function businessSearchParametersV2(\StructType\BusinessSearchParametersV2RequestType $parameters)
    {
        try {
            $this->setResult($this->getSoapClient()->businessSearchParametersV2($parameters));
            return $this->getResult();
        } catch (\SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return \StructType\BusinessBIKToSBIResponseType|\StructType\BusinessGetBIKDescriptionResponseType|\StructType\BusinessGetDossierExtendedResponseType|\StructType\BusinessGetDossierSBIResponseType|\StructType\BusinessGetDossierV3ResponseType|\StructType\BusinessGetEstablishmentNumberResponseType|\StructType\BusinessGetSBIDescriptionResponseType|\StructType\BusinessSBIToBIKResponseType|\StructType\BusinessSearchAddressResponseType|\StructType\BusinessSearchDossierNumberResponseType|\StructType\BusinessSearchNameResponseType|\StructType\BusinessSearchParametersResponseType|\StructType\BusinessSearchParametersV2ResponseType|\StructType\BusinessSearchParametersV3ResponseType|\StructType\BusinessSearchPostcodeResponseType|\StructType\BusinessSearchSelectionResponseType|\StructType\BusinessSearchSelectionV2ResponseType|\StructType\BusinessUpdateAddDossierResponseType|\StructType\BusinessUpdateCheckDossierResponseType|\StructType\BusinessUpdateGetChangedDossiersResponseType|\StructType\BusinessUpdateGetDossiersResponseType|\StructType\BusinessUpdateRemoveDossierResponseType
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
